/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT license.
 */
export declare type Bounds = readonly [number, number];
export declare type BiIndex = readonly [number, number];
declare type CostFn<T, U> = (o?: T, m?: U) => number;
export default class Alignment {
    readonly values: readonly BiIndex[];
    readonly length: number;
    constructor(values: Iterable<BiIndex>);
    static identity(size: number): Alignment;
    static identity(start: number, end: number): Alignment;
    static identity(bounds: Bounds): Alignment;
    static infer<T, U>(original: Iterable<T>, modified: Iterable<U>, costFn?: CostFn<T, U>): Alignment;
    private static _inferRecursive;
    private static _inferCosts;
    private static _inferMatrix;
    slice(start?: number, end?: number): Alignment;
    private _search;
    private _bounds;
    originalBounds(): Bounds;
    originalBounds(start: number, end: number): Bounds;
    originalBounds(bounds: Bounds): Bounds;
    modifiedBounds(): Bounds;
    modifiedBounds(start: number, end: number): Bounds;
    modifiedBounds(bounds: Bounds): Bounds;
    private _sliceBy;
    sliceByOriginal(start: number, end: number): Alignment;
    sliceByOriginal(bounds: Bounds): Alignment;
    sliceByModified(start: number, end: number): Alignment;
    sliceByModified(bounds: Bounds): Alignment;
    shift(deltaO: number, deltaM: number): Alignment;
    concat(...others: Alignment[]): Alignment;
    compose(other: Alignment): Alignment;
    inverse(): Alignment;
    equals(other: Alignment): boolean;
}
export {};
//# sourceMappingURL=alignment.d.ts.map