/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT license.
 */
import Alignment, { Bounds } from "./alignment";
import { Replacer } from "./regex";
export declare type AnyString = string | BiString;
export default class BiString implements Iterable<String> {
    readonly original: string;
    readonly modified: string;
    readonly alignment: Alignment;
    readonly length: number;
    readonly [i: number]: string;
    constructor(original: string, modified?: string, alignment?: Alignment);
    static from(str: AnyString): BiString;
    static infer(original: string, modified: string): BiString;
    [Symbol.iterator](): IterableIterator<string>;
    charAt(pos: number): string;
    charCodeAt(pos: number): number;
    codePointAt(pos: number): number | undefined;
    substring(start: number, end?: number): BiString;
    slice(start: number, end?: number): BiString;
    concat(...others: AnyString[]): BiString;
    inverse(): BiString;
    equals(other: BiString): boolean;
    indexOf(searchValue: string, fromIndex?: number): number;
    lastIndexOf(searchValue: string, fromIndex?: number): number;
    boundsOf(searchValue: string, fromIndex?: number): Bounds;
    lastBoundsOf(searchValue: string, fromIndex?: number): Bounds;
    search(regexp: RegExp): number;
    searchBounds(regexp: RegExp): Bounds;
    match(regexp: RegExp): RegExpMatchArray | null;
    matchAll(regexp: RegExp): IterableIterator<RegExpMatchArray>;
    private _replaceString;
    private _replaceRegExp;
    replace(pattern: string | RegExp, replacement: string | Replacer): BiString;
    trim(): BiString;
    trimStart(): BiString;
    trimEnd(): BiString;
    padStart(targetLength: number, padString?: string): BiString;
    padEnd(targetLength: number, padString?: string): BiString;
    startsWith(searchString: string, position?: number): boolean;
    endsWith(searchString: string, position?: number): boolean;
    private _splitString;
    private _splitRegExp;
    split(separator?: string | RegExp, limit?: number): BiString[];
    join(items: Iterable<AnyString>): BiString;
    private static _normalFormRegex;
    normalize(form: "NFC" | "NFD" | "NFKC" | "NFKD"): BiString;
    private _isFinalSigmaAt;
    toLowerCase(): BiString;
    toUpperCase(): BiString;
}
//# sourceMappingURL=bistring.d.ts.map