/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT license.
 */
import Alignment, { Bounds } from "./alignment";
import BiString, { AnyString } from "./bistring";
export declare class Token {
    readonly text: BiString;
    readonly start: number;
    readonly end: number;
    constructor(text: AnyString, start: number, end: number);
    static slice(text: AnyString, start: number, end: number): Token;
    get original(): string;
    get modified(): string;
}
export declare class Tokenization {
    readonly text: BiString;
    readonly tokens: readonly Token[];
    readonly alignment: Alignment;
    readonly length: number;
    constructor(text: AnyString, tokens: Iterable<Token>);
    static infer(text: AnyString, tokens: Iterable<string>): Tokenization;
    slice(start?: number, end?: number): Tokenization;
    substring(start?: number, end?: number): BiString;
    textBounds(start?: number, end?: number): Bounds;
    originalBounds(start?: number, end?: number): Bounds;
    boundsForText(start: number, end: number): Bounds;
    boundsForOriginal(start: number, end: number): Bounds;
    sliceByText(start: number, end: number): Tokenization;
    sliceByOriginal(start: number, end: number): Tokenization;
    snapTextBounds(start: number, end: number): Bounds;
    snapOriginalBounds(start: number, end: number): Bounds;
}
export interface Tokenizer {
    tokenize(text: AnyString): Tokenization;
}
export declare class RegExpTokenizer implements Tokenizer {
    private readonly _pattern;
    constructor(pattern: RegExp);
    tokenize(text: AnyString): Tokenization;
}
export declare class SplittingTokenizer implements Tokenizer {
    private readonly _pattern;
    constructor(pattern: RegExp);
    tokenize(text: AnyString): Tokenization;
}
//# sourceMappingURL=token.d.ts.map